/*
 * Copyright (c) 1996, 1998, Oracle and/or its affiliates. All rights reserved.
 * Copyright 2018-2022 MicroEJ Corp. This file has been modified by MicroEJ Corp.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */

package java.security;

import ej.annotation.Nullable;

/**
 * This interface represents the abstract notion of a principal, which can be used to represent any entity, such as an
 * individual, a corporation, and a login id.
 *
 * @see java.security.cert.X509Certificate
 *
 * @author Li Gong
 */
public interface Principal {

	/**
	 * Compares this principal to the specified object. Returns true if the object passed in matches the principal
	 * represented by the implementation of this interface.
	 *
	 * @param another
	 *            principal to compare with.
	 *
	 * @return true if the principal passed in is the same as that encapsulated by this principal, and false otherwise.
	 *
	 */
	@Override
	public boolean equals(@Nullable Object another);

	/**
	 * Returns a string representation of this principal.
	 *
	 * @return a string representation of this principal.
	 */
	@Override
	public String toString();

	/**
	 * Returns a hashcode for this principal.
	 *
	 * @return a hashcode for this principal.
	 */
	@Override
	public int hashCode();
}
